@@ -15,7 +15,7 @@
  *
  */
 /*
- *  Copyright (C) 2000-2022 Thomas Habets <thomas@habets.se>
+ *  Copyright (C) 2000-2024 Thomas Habets <thomas@habets.se>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -186,7 +186,7 @@ uint32_t dstip;
 static uint8_t dstmac[ETH_ALEN];
 
 static char* payload_suffix = NULL;
-static size_t payload_suffix_size = 4;
+static const size_t payload_suffix_size = 4;
 
 /* If there were any libnet write failures, we return error. */
 static size_t libnet_write_failures = 0;
@@ -382,7 +382,7 @@ parse_ulong(const char* in, const char* what, char* ebuf, size_t ebuflen)
 static ssize_t
 xgetrandom(void *buf, const size_t buflen, const unsigned int flags)
 {
-#ifdef HAVE_GETRANDOM
+#ifdef ACTUALLY_HAVE_GETRANDOM
         return getrandom(buf, buflen, flags);
 #else
         UNUSED(flags);
@@ -499,7 +499,7 @@ drop_uid(uid_t uid, gid_t gid)
 static void
 drop_capabilities()
 {
-#if HAVE_CAP_INIT
+#ifdef ACTUALLY_HAVE_CAP_INIT
         cap_t no_cap;
         if (!(no_cap = cap_init())) {
                 if (verbose) {
